import tecplot as tp
import numpy as np
import os
from tecplot.exception import *
from tecplot.constant import *

# Uncomment the following line to connect to a running instance of Tecplot 360:
tp.session.connect()

#### inputs
zval = -0.035
num_levels = 25
analysis_var_name = 'Total Pressure'
rad_var_name = 'R'

#######

tp.new_layout()
tp.data.load_tecplot(os.path.join(os.getcwd(),'Axial.plt'))

plot = tp.active_frame().plot()
dataset = tp.active_frame().dataset

extract_slice = tp.data.extract.extract_slice(origin = (0,0,zval), 
                                              normal = (0,0,1))

radius_var = dataset.variable(rad_var_name)
analysis_var = dataset.variable(analysis_var_name)

plot.contour(0).variable = radius_var
plot.contour(0).levels.reset_levels(np.linspace(radius_var.min(), radius_var.max(),num_levels))
plot.show_contour=True

plot.fieldmap(extract_slice).contour.contour_type=ContourType.Lines


num_init_zones = dataset.num_zones
print(num_init_zones)
tp.macro.execute_command('''$!CreateContourLineZones 
  ContLineCreateMode = OneZonePerContourLevel''')
final_cont_zones = dataset.num_zones
print(final_cont_zones)

final_var_values = []
final_rad_values = []

radius_var = dataset.variable(rad_var_name)
totpress_var = dataset.variable(analysis_var_name)

for i in range(num_init_zones, final_cont_zones):
    print("Averaging {}".format(i))
    curzone = dataset.zone(i)
    rad = curzone.values(radius_var)[0]
    vals  = curzone.values(totpress_var).as_numpy_array()
    avg = np.average(vals)
    
    final_var_values.append(avg)
    final_rad_values.append(rad)


tp.macro.execute_command('''$!CreateRectangularZone 
  IMax = {}
  JMax = 1
  KMax = 1
  '''.format(final_cont_zones-num_init_zones))

print("Populating zone")
result_zone = dataset.zone(-1)
    
result_zone.values(totpress_var)[:] = final_var_values
result_zone.values(radius_var)[:] = final_rad_values
    
print("Creating line plot")
tp.macro.execute_command('''$!CreateNewFrame 
  XYPos
    {
    X = 4.3451
    Y = 4.0199
    }
  Width = 5.354
  Height = 4.2655''')
line_frame = tp.active_frame()
line_frame.plot_type=PlotType.XYLine
line_plot = line_frame.plot()
line_plot.delete_linemaps()
line_plot.add_linemap()
line_plot.linemap(0).name='Map 0'
line_plot.linemap(0).x_variable = analysis_var
line_plot.linemap(0).y_variable = radius_var
line_plot.linemap(0).zone = result_zone
line_plot.linemap(0).show=True
line_plot.view.fit()
line_plot.show_symbols=True

