import sys
import tecplot as tp
from tecplot.constant import *
import recorded_refined_as_functions as tp_funs
from PyQt4 import QtGui, QtCore


tp.session.connect()
floatval = 10000
num_levels = 25

class Example(QtGui.QWidget):
    
    def __init__(self):
        super(Example, self).__init__()
        
        self.initUI()
        
           
        
    def initUI(self):

        self.lcd = QtGui.QLCDNumber(self)
        self.sld = QtGui.QSlider(QtCore.Qt.Horizontal, self)
        self.btn1 = QtGui.QPushButton("Load data", self)
        self.btn2 = QtGui.QPushButton("Set Slice Location", self)
        self.line_plt = None
        self.mainframe = tp.active_frame()
        vbox = QtGui.QVBoxLayout()
        vbox.addWidget(self.btn1)
        vbox.addWidget(self.lcd)
        vbox.addWidget(self.sld)
        vbox.addWidget(self.btn2)

        self.setLayout(vbox)
        if self.mainframe.plot_type == PlotType.Cartesian3D:
            self.updateSliderMinMax()
        self.sld.valueChanged.connect(self.update_display)
        self.btn1.clicked.connect(self.dataButtonClicked)
        self.btn2.clicked.connect(self.sliceButtonClicked)
        
        self.setGeometry(300, 300, 250, 150)
        self.setWindowTitle('Set Z position')
        self.show()

        
    def updateSliderMinMax(self):
        plot = tp.active_frame().plot()
        z_var = plot.axes.z_axis.variable
        self.sld.setMinimum(z_var.min()*floatval)
        self.sld.setMaximum(z_var.max()*floatval)
        
    def dataButtonClicked(self):
        
        tp.new_layout()
        tp_funs.dataset_setup()
        ds = tp.active_frame().dataset
        self.updateSliderMinMax() 
        self.mainframe = tp.active_frame()
        
        
    def sliceButtonClicked(self):
        self.mainframe.activate()
        ds = tp.active_frame().dataset
        analysis_var = ds.variable('total pressure')
        radius_var = ds.variable('R')
        z_pos = float(self.sld.value())/floatval
        mainplot = self.mainframe.plot()
        tp_funs.setup_slices(mainplot, z_pos)
        tp.macro.execute_command('''$!CreateRectangularZone 
          IMax = {}
         JMax = 1
          KMax = 1
          '''.format(num_levels-1))        
        result_zone = ds.zone(-1)
        result_zone.name = "Average at z = {}".format(z_pos)
        
        tp_funs.calc_radial_average(z_pos, radius_var, analysis_var, num_levels, 
                                    result_zone, mainplot, ds)
        
        if self.line_plt != None: 
            tp_funs.update_lineplot(self.line_plt, result_zone, analysis_var, 
                                   radius_var)
        else:
            self.line_plt = tp_funs.create_lineplot_frame(result_zone, analysis_var,radius_var)        
            
    def update_display(self, value):
        dec = value/floatval
        self.lcd.display(dec)  
        
        
def main():
    
    app = QtGui.QApplication(sys.argv)
    ex = Example()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()