import os
import tecplot as tp
import numpy as np

from tecplot.exception import *
from tecplot.constant import *

def dataset_setup():
    tp.new_layout()
    tp.data.load_tecplot(os.path.join(os.getcwd(),'Axial.plt'))
    

def setup_slices(plot,zval):
    plot.show_slices = True
    slices = plot.slice(0)
    slices.contour.show = False
    slices.shade.color = Color.Blue
    slices.shade.show = True
    slices.show = True
    slices.orientation=SliceSurface.ZPlanes
    slices.origin = (0,0,zval)    

def calc_radial_average(zval, radius_var, analysis_var, num_points, result_zone, plot,dataset):
    
    plot.activate() 
    plot.frame.activate()
    extract_slice = tp.data.extract.extract_slice(origin = (0,0,zval), 
                                              normal = (0,0,1))
    

    plot.contour(0).variable = radius_var
    plot.contour(0).levels.reset_levels(np.linspace(radius_var.values(extract_slice).min(), 
                                                    radius_var.values(extract_slice).max(),
                                                    num_points))
    plot.show_contour=True
    plot.fieldmap(extract_slice).contour.contour_type=ContourType.Lines
    


    num_init_zones = dataset.num_zones
    
    tp.macro.execute_command('''$!CreateContourLineZones 
    ContLineCreateMode = OneZonePerContourLevel''')
    final_cont_zones = dataset.num_zones
    
    
    final_var_values = []
    final_rad_values = []
    created_zones = [extract_slice]
  
    for i in range(num_init_zones, final_cont_zones):
        curzone = dataset.zone(i)
        created_zones.append(curzone)
        rad = float(curzone.name.split('=')[1].split('e')[0])
        vals  = curzone.values(analysis_var).as_numpy_array()
        avg = np.average(vals)
        
        final_var_values.append(avg)
        final_rad_values.append(rad)
        
    dataset.delete_zones(created_zones)
    
           
    result_zone.values(analysis_var)[:] = final_var_values
    result_zone.values('R')[:] = final_rad_values
    
    
def create_lineplot_frame(result_zone, analysis_var, radius_var):
    tp.macro.execute_command('''$!CreateNewFrame 
      XYPos
        {
        X = 4.3451
        Y = 4.0199
        }
      Width = 5.354
      Height = 4.2655''')
    line_frame = tp.active_frame()
    line_frame.plot_type=PlotType.XYLine
    line_plot = line_frame.plot()
    line_plot.delete_linemaps()
    update_lineplot(line_plot, result_zone, analysis_var, radius_var)
    line_plot.view.fit()
    line_plot.show_symbols=True
    return line_plot

def update_lineplot(line_plot, result_zone, analysis_var, radius_var):
    lm = line_plot.add_linemap()
    lm.name='&ZN&'
    lm.x_variable = analysis_var
    lm.y_variable = radius_var
    lm.zone = result_zone
    lm.show=True    
    line_plot.view.fit()
    

